==> deepin-boot-maker_5.6.5+dfsg.orig.tar.gz: deepin-boot-maker_5.6.5+dfsg/src/translations/deepin-boot-maker_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="12"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="15"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation>Espace disque insuffisant : assurez-vous que le disque dispose de suffisamment d&apos;espace libre</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="18"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation>Erreur montage disque : Veuillez réinsérer le disque ou redémarrer le système</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="21"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation>Erreur décompression image : Vérifiez la somme de contrôle MD5 de l&apos;image et assurez-vous de son intégrité</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="24"/>
        <source>Internal Error</source>
        <translation>Erreur Interne</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="79"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation>Boot Maker est un outil simple pour écrire des fichiers image système sur des lecteurs flash USB et d&apos;autres supports.</translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="81"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="125"/>
        <source>Drag an ISO image file here</source>
        <translation>Faites glisser un fichier d&apos;image ISO ici</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="144"/>
        <source>OR</source>
        <translation>OU</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="89"/>
        <location filename="../app/view/isoselectview.cpp" line="163"/>
        <source>Select an ISO image file</source>
        <translation>Sélectionner une image ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="214"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="300"/>
        <source>Reselect an ISO image file</source>
        <translation>Sélectionner une autre image ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="237"/>
        <source>Illegal ISO image file</source>
        <translation>Fichier image ISO illégal</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="441"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>Détection du fichier ISO, veuillez patienter...</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="62"/>
        <source>Burning</source>
        <translation>Gravage</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="78"/>
        <source>Burning, please wait...</source>
        <translation>Gravage, veuillez patienter...</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="90"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>Veuillez ne pas retirer le disque ou éteindre l&apos;ordinateur pendant le traitement</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="112"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation>Périphérique amovible</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="221"/>
        <location filename="../libdbm/util/utils.cpp" line="365"/>
        <source>Removable disk</source>
        <translation>Périphérique amovible</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="118"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="149"/>
        <source>Reboot now</source>
        <translation>Redémarrer</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="132"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="66"/>
        <source>Successful</source>
        <translation>Réussi </translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="229"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation>Le journal des erreurs sera automatiquement envoyé avec des annotations. Sans cela nous ne pouvons pas améliorer le programme</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="230"/>
        <source>Submit Feedback</source>
        <translation>Envoyer des commentaires</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="253"/>
        <source>After-Sale Services</source>
        <translation>Services après-vente</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="269"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="277"/>
        <source>Sorry, process failed</source>
        <translation>Désolé, le processus a échoué</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="278"/>
        <source>Process failed</source>
        <translation>Échec du processus</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="13"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation>Vérification des données et retrait du support en toute sécurité, veuillez patienter...</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="87"/>
        <source>Select a partition</source>
        <translation>Sélectionner une partition</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="114"/>
        <source>Format the partition</source>
        <translation>Formater la partition</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="162"/>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="166"/>
        <source>Back</source>
        <translation>Retour</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="222"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation>Le formatage effacera toutes les données de la partition, mais peut augmenter le taux de réussite, veuillez confirmer avant de continuer</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="318"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation>Le formatage de la partition écrasera toutes les données, veuillez avoir une sauvegarde avant de continuer.</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="335"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation>Erreur de format de disque : veuillez formater la partition en FAT32</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="147"/>
        <source>No disk available</source>
        <translation>Aucun disque disponible</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="316"/>
        <source>Format Partition</source>
        <translation>Formater la partition</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="319"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="320"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>

==> deepin-boot-maker_5.6.12+dfsg.orig.tar.gz: deepin-boot-maker_5.6.12+dfsg/src/translations/deepin-boot-maker_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="16"/>
        <source>Disk Format Error: Please reformat it or disable &quot;Auto scan USB storage devices&quot; in Security Center</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="19"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation>Erreur de format de disque : veuillez le reformater</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="24"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation>Espace disque insuffisant : assurez-vous que le disque dispose de suffisamment d&apos;espace libre</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="27"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation>Erreur montage disque : Veuillez réinsérer le disque ou redémarrer le système</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="30"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation>Erreur décompression image : Vérifiez la somme de contrôle MD5 de l&apos;image et assurez-vous de son intégrité</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="33"/>
        <source>Internal Error</source>
        <translation>Erreur Interne</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="79"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation>Boot Maker est un outil simple pour écrire des fichiers image système sur des lecteurs flash USB et d&apos;autres supports.</translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="81"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="126"/>
        <source>Drag an ISO image file here</source>
        <translation>Faites glisser un fichier d&apos;image ISO ici</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="145"/>
        <source>OR</source>
        <translation>OU</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="89"/>
        <location filename="../app/view/isoselectview.cpp" line="163"/>
        <source>Select an ISO image file</source>
        <translation>Sélectionner une image ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="211"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="297"/>
        <source>Reselect an ISO image file</source>
        <translation>Sélectionner une autre image ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="234"/>
        <source>Illegal ISO image file</source>
        <translation>Fichier image ISO illégal</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="438"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>Détection du fichier ISO, veuillez patienter...</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="62"/>
        <source>Burning</source>
        <translation>Gravage</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="78"/>
        <source>Burning, please wait...</source>
        <translation>Gravage, veuillez patienter...</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="90"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>Veuillez ne pas retirer le disque ou éteindre l&apos;ordinateur pendant le traitement</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="112"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation>Périphérique amovible</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="223"/>
        <location filename="../libdbm/util/utils.cpp" line="369"/>
        <source>Removable disk</source>
        <translation>Périphérique amovible</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="118"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="137"/>
        <source>Reboot now</source>
        <translation>Redémarrer</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="120"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="68"/>
        <source>Successful</source>
        <translation>Réussi </translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="217"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation>Le journal des erreurs sera automatiquement envoyé avec des annotations. Sans cela nous ne pouvons pas améliorer le programme</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="218"/>
        <source>Submit Feedback</source>
        <translation>Envoyer des commentaires</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="241"/>
        <source>After-Sale Services</source>
        <translation>Services après-vente</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="254"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="262"/>
        <source>Sorry, process failed</source>
        <translation>Désolé, le processus a échoué</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="263"/>
        <source>Process failed</source>
        <translation>Échec du processus</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="13"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation>Vérification des données et retrait du support en toute sécurité, veuillez patienter...</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="95"/>
        <source>Select a partition</source>
        <translation>Sélectionner une partition</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="122"/>
        <source>Format the partition</source>
        <translation>Formater la partition</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="171"/>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="175"/>
        <source>Back</source>
        <translation>Retour</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="231"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation>Le formatage effacera toutes les données de la partition, mais peut augmenter le taux de réussite, veuillez confirmer avant de continuer</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="368"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation>Le formatage de la partition écrasera toutes les données, veuillez avoir une sauvegarde avant de continuer.</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="402"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation>Erreur de format de disque : veuillez formater la partition en FAT32</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="156"/>
        <source>No disk available</source>
        <translation>Aucun disque disponible</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="365"/>
        <source>Format Partition</source>
        <translation>Formater la partition</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="372"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="374"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>
